Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(746)

Unified Diff: Source/core/events/Event.h

Issue 1352523002: Use high precision timestamp for Event.timestamp (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Use m_target to find event document Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/core/events/Event.h
diff --git a/Source/core/events/Event.h b/Source/core/events/Event.h
index f0ee9c3637b3875a633d56950d83e070999912c5..18cbf4c236e5d1b657fb6c71daf8cf0b41b9c08f 100644
--- a/Source/core/events/Event.h
+++ b/Source/core/events/Event.h
@@ -122,7 +122,10 @@ public:
bool bubbles() const { return m_canBubble; }
bool cancelable() const { return m_cancelable; }
- DOMTimeStamp timeStamp() const { return m_createTime; }
+
+ // Event creation timestamp in milliseconds
+ double timeStamp() const;
dtapuska 2015/09/18 16:04:42 I think there should be a specific call for gettin
majidvp 2015/09/18 17:43:33 Agreed. I like to keep timeStamp() to be the metho
+ double timeStampForPlatformInSeconds() const;
Rick Byers 2015/09/18 15:56:32 nit: add comment for the new method (i.e. what "fo
majidvp 2015/09/18 17:43:34 Acknowledged.
void stopPropagation() { m_propagationStopped = true; }
void stopImmediatePropagation() { m_immediatePropagationStopped = true; }
@@ -225,7 +228,7 @@ private:
DOMTimeStamp m_createTime;
RefPtrWillBeMember<Event> m_underlyingEvent;
OwnPtrWillBeMember<EventPath> m_eventPath;
- double m_uiCreateTime; // For input events, the time the event was recorded by the UI.
+ double m_uiCreateTime; // For input events, the time the event was recorded by the UI in seconds.
dtapuska 2015/09/18 16:04:42 When indicating time; be sure to reference what cl
majidvp 2015/09/18 17:43:34 Acknowledged.
};
#define DEFINE_EVENT_TYPE_CASTS(typeName) \

Powered by Google App Engine
This is Rietveld 408576698